History
-------

0.1.1
+++++

Expanding the Filesystem metaphor:
Client now has rm_rf() and rm() methods

Queues now have variable item prefix (Useful for watching Queues created by other libraries)
Queues now have multiple watch options - watch for lists of items, or data added.

0.1 (2012-05-07)
++++++++++++++++++

Initial release with
* complete CRUD
* Lock Implementation
* Queue Implementation
